﻿/* LoadFileCommand
 * Product: Mud Designer Engine
 * Copyright (c) 2012 AllocateThis! Studios. All rights reserved.
 * http://MudDesigner.Codeplex.com
 *  
 * File Description: Provides support for loading the game world.  This is an admin only command.
 */

//Microsoft .NET using statements
using System;
using System.Collections.Generic;
using System.IO;

//AllocateThis! Mud Designer using statements
using MudDesigner.Engine.Objects;
using MudDesigner.Engine.Core;
using MudDesigner.Engine.Scripting;
using MudDesigner.Engine.Mobs;
using log4net;

namespace MudDesigner.Engine.Commands
{
    /// <summary>
    /// Provides support for loading the game world.  This is an admin only command.
    /// </summary>
    public class LoadFileCommand : ICommand
    {
        private static readonly ILog Log = LogManager.GetLogger(typeof(LoadFileCommand)); 

        public void Execute(IPlayer player)
        {
            //if the player has the correct role..
            if (player != null && (player.Role == CharacterRoles.Owner || player.Role == CharacterRoles.Admin))
            {
                if (player.Director.Server.Game != null)
                {
                    //Restore the world to the state it was in prior to the last save.
                    player.Director.Server.Game.RestoreWorld();
                    player.SendMessage("World restoration completed.");
                    Log.Info("World restoration completed.");

                }
            }
        }
    }
}